#[non_exhaustive]pub struct AssociatedSourceBuilder { /* private fields */ }Expand description
A builder for AssociatedSource.
Implementations
Sourceimpl AssociatedSourceBuilder
impl AssociatedSourceBuilder
The Amazon Resource Name (ARN) of the resource share that contains the source association.
The Amazon Resource Name (ARN) of the resource share that contains the source association.
The Amazon Resource Name (ARN) of the resource share that contains the source association.
Sourcepub fn source_id(self, input: impl Into<String>) -> Self
pub fn source_id(self, input: impl Into<String>) -> Self
The identifier of the source. This can be an account ID, Amazon Resource Name (ARN), organization ID, or organization path.
Sourcepub fn set_source_id(self, input: Option<String>) -> Self
pub fn set_source_id(self, input: Option<String>) -> Self
The identifier of the source. This can be an account ID, Amazon Resource Name (ARN), organization ID, or organization path.
Sourcepub fn get_source_id(&self) -> &Option<String>
pub fn get_source_id(&self) -> &Option<String>
The identifier of the source. This can be an account ID, Amazon Resource Name (ARN), organization ID, or organization path.
Sourcepub fn source_type(self, input: impl Into<String>) -> Self
pub fn source_type(self, input: impl Into<String>) -> Self
The type of source.
Sourcepub fn set_source_type(self, input: Option<String>) -> Self
pub fn set_source_type(self, input: Option<String>) -> Self
The type of source.
Sourcepub fn get_source_type(&self) -> &Option<String>
pub fn get_source_type(&self) -> &Option<String>
The type of source.
Sourcepub fn status(self, input: impl Into<String>) -> Self
pub fn status(self, input: impl Into<String>) -> Self
The current status of the source association.
Sourcepub fn set_status(self, input: Option<String>) -> Self
pub fn set_status(self, input: Option<String>) -> Self
The current status of the source association.
Sourcepub fn get_status(&self) -> &Option<String>
pub fn get_status(&self) -> &Option<String>
The current status of the source association.
Sourcepub fn last_updated_time(self, input: DateTime) -> Self
pub fn last_updated_time(self, input: DateTime) -> Self
The date and time when the source association was last updated.
Sourcepub fn set_last_updated_time(self, input: Option<DateTime>) -> Self
pub fn set_last_updated_time(self, input: Option<DateTime>) -> Self
The date and time when the source association was last updated.
Sourcepub fn get_last_updated_time(&self) -> &Option<DateTime>
pub fn get_last_updated_time(&self) -> &Option<DateTime>
The date and time when the source association was last updated.
Sourcepub fn creation_time(self, input: DateTime) -> Self
pub fn creation_time(self, input: DateTime) -> Self
The date and time when the source association was created.
Sourcepub fn set_creation_time(self, input: Option<DateTime>) -> Self
pub fn set_creation_time(self, input: Option<DateTime>) -> Self
The date and time when the source association was created.
Sourcepub fn get_creation_time(&self) -> &Option<DateTime>
pub fn get_creation_time(&self) -> &Option<DateTime>
The date and time when the source association was created.
Sourcepub fn status_message(self, input: impl Into<String>) -> Self
pub fn status_message(self, input: impl Into<String>) -> Self
A message about the status of the source association.
Sourcepub fn set_status_message(self, input: Option<String>) -> Self
pub fn set_status_message(self, input: Option<String>) -> Self
A message about the status of the source association.
Sourcepub fn get_status_message(&self) -> &Option<String>
pub fn get_status_message(&self) -> &Option<String>
A message about the status of the source association.
Sourcepub fn build(self) -> AssociatedSource
pub fn build(self) -> AssociatedSource
Consumes the builder and constructs a AssociatedSource.