#[non_exhaustive]pub struct AssociatedSource {
pub resource_share_arn: Option<String>,
pub source_id: Option<String>,
pub source_type: Option<String>,
pub status: Option<String>,
pub last_updated_time: Option<DateTime>,
pub creation_time: Option<DateTime>,
pub status_message: Option<String>,
}Expand description
Information about a source association in a resource share. Source associations control which sources can be used with service principals.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.The Amazon Resource Name (ARN) of the resource share that contains the source association.
source_id: Option<String>The identifier of the source. This can be an account ID, Amazon Resource Name (ARN), organization ID, or organization path.
source_type: Option<String>The type of source.
status: Option<String>The current status of the source association.
last_updated_time: Option<DateTime>The date and time when the source association was last updated.
creation_time: Option<DateTime>The date and time when the source association was created.
status_message: Option<String>A message about the status of the source association.
Implementations
Sourceimpl AssociatedSource
impl AssociatedSource
The Amazon Resource Name (ARN) of the resource share that contains the source association.
Sourcepub fn source_id(&self) -> Option<&str>
pub fn source_id(&self) -> Option<&str>
The identifier of the source. This can be an account ID, Amazon Resource Name (ARN), organization ID, or organization path.
Sourcepub fn source_type(&self) -> Option<&str>
pub fn source_type(&self) -> Option<&str>
The type of source.
Sourcepub fn last_updated_time(&self) -> Option<&DateTime>
pub fn last_updated_time(&self) -> Option<&DateTime>
The date and time when the source association was last updated.
Sourcepub fn creation_time(&self) -> Option<&DateTime>
pub fn creation_time(&self) -> Option<&DateTime>
The date and time when the source association was created.
Sourcepub fn status_message(&self) -> Option<&str>
pub fn status_message(&self) -> Option<&str>
A message about the status of the source association.
Sourceimpl AssociatedSource
impl AssociatedSource
Sourcepub fn builder() -> AssociatedSourceBuilder
pub fn builder() -> AssociatedSourceBuilder
Creates a new builder-style object to manufacture AssociatedSource.